# Cudo Compute
To use this client install cudoctl and run ``./cudoctl init`` follow the steps to enter your API key and choose your project.  

Then when you call CudoClient in python it will grab your API key from the yaml file created by cudoctl.

```bash
pip install cudo-compute
```

```python
import cudo_compute as cudo

client, e = cudo.CudoClient.get_client()
api = cudo.VirtualMachinesApi(client)
```

A more complete example of various api calls can be seen in the example in ``examples/example.py`` demonstrates how to use it. 



# Advanced Users / Development
The code is generated by swagger codegen cli.

Most code is generated in github actions see .github/workflows the generated code is put into a /src/cudo_compute directory
The code gets modified and the helpers get copied in from /helpers.

``./codegen.sh`` generates src file with example client for local experimentation

If you wish to customise how the API key or project is selected see the code in the helpers directory. 